<?php
/**
 * IpRangeReal permission provider for VuFind.
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2007.
 * Copyright (C) Leipzig University Library 2022.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Authorization
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
namespace finc\Role\PermissionProvider;

/**
 * IpRangeReal permission provider for VuFind.
 *
 * @category VuFind
 * @package  Authorization
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
class IpRangeReal extends \finc\Role\PermissionProvider\IpRangeFoFor
{
    /**
     * Returns remote address based on eventual proxy headers
     *
     * @return string
     */
    protected function getRemoteAddr()
    {
        // often provided by nginx-reverse-proxies, should be used since its the nature of the value
        if ($ip = $this->request->getServer()->get('HTTP_X_REAL_IP')) {
            return $ip;
        }

        return $this->request->getServer()->get('REMOTE_ADDR');
    }
}
