<?php
namespace Selenium\adlr;

use Facebook\WebDriver\WebDriverBy;
use Facebook\WebDriver\WebDriverExpectedCondition;
use Lmc\Steward\ConfigProvider;
use Lmc\Steward\Test\AbstractTestCase;

class AdlrBase extends AbstractTestCase
{
    public static $port = '';
    // public static $port = ':81';

    /** @var string */
    public static $host = 'https://staging.finc.info/vufind2/fid_adlr';
    // public static $baseUrl = 'http://host.docker.internal';
    // public static $baseUrl = 'http://127.0.0.1';
    // public static $baseUrl = 'http://localhost';

    protected $user = false;

    /**
     * @before
     */
    public function initBaseUrl()
    {
        // Set base url according to environment
        switch (ConfigProvider::getInstance()->env) {
            case 'staging':
                self::$host = 'https://staging.finc.info/vufind2/fid_adlr';
                break;
            case 'alpha':
                self::$host = 'http://host.docker.internal';
                // self::$host = 'https://alpha.finc.info/vufind2/fid_adlr/22589';
                break;
            case 'local':
                self::$host = 'http://host.docker.internal';
                break;
            default:
                throw new \RuntimeException(sprintf('Unknown environment "%s"', ConfigProvider::getInstance()->env));
        }

        $this->debug('Environment "%s"', ConfigProvider::getInstance()->env);
        $this->debug('Base URL set to "%s"', self::$host);

        if (ConfigProvider::getInstance()->env === 'production') {
            $this->warn('The tests are run against production, so be careful!');
        }
    }

    protected function runGetItTest($records = [], $rules = []): void
    {
        foreach ($records as $record) {
            $this->log("object id of webdriver: " . spl_object_id($this->wd));
            $this->wd->get(self::$host . self::$port . $record);
            $this->wd->takeScreenshot("logs/adlr/info{$record}" . ($this->user ? '-' . $this->user : '') . ".png");

            foreach ($rules["desc"] ?? [] as $rule) {
                if ($rule["waitForClass"]) {
                    $this->waitForClass($rule["waitForClass"], true);
                }
                if ($rule["waitForId"]) {
                    $this->waitForId($rule["waitForId"], true);
                }
                if ($rule["waitForLinkText"]) {
                    $this->waitForLinkText($rule["waitForLinkText"], true);
                }
                if ($rule["wait"]) {
                    try {
                        $this->wd->wait(5, 5000)->until(
                            WebDriverExpectedCondition::elementTextContains(
                                WebDriverBy::className($rule["wait"]),
                                $rule["text"]
                            )
                        );
                    } catch (\Facebook\WebDriver\Exception\NoSuchElementException $x) {
                        $this->log("Timeout for $record when fething {$rule["wait"]}.");
                    }
                }
                try {
                    $value = $this->findByCss($rule["path"])->getText();
                } catch (\Facebook\WebDriver\Exception\NoSuchElementException $x) {
                    $value = false;
                }
                switch ($rule["type"] ?? '') {
                    case 'text':
                        $this->assertEqualsIgnoringCase(
                            $rule["text"],
                            $value,
                            $rule["path"] . ($value === false ? " does not exists" : " is '" . $value . "' ")
                            . ", but should be '" . $rule["text"] . "'"
                        );
                        break;
                    case 'contains':
                        $this->assertStringContainsStringIgnoringCase(
                            $rule["text"],
                            $value,
                            $record . ": " .
                            $rule["path"] . ($value === false ? " does not exists" : " is '" . $value . "' ")
                            . ", but should contain '" . $rule["text"] . "'"
                        );
                        break;
                    case 'anti-exi':
                        $this->assertNotEqualsIgnoringCase(
                            $rule["text"],
                            $value,
                            $rule["path"] . " must not be equals to '" . $rule["text"] . "'"
                        );
                        break;
                }
            }
        }
    }

    #region helper methods
    protected function changeLanguage($lang = 'de')
    {
        $this->wd->get(self::$host . self::$port);
        $this->wd->executeScript("document.langForm.mylang.value='" . $lang . "';document.langForm.submit();");
        $this->waitForPartialLinkText('MENÜ');
    }

    protected function setFullsreen()
    {
        $this->wd->manage()->window()->maximize();
    }

    protected function logout()
    {
        $this->wd->get(self::$host . self::$port . '/MyResearch/Logout');
    }

    protected function setUp(): void
    {
        $this->changeLanguage();
        parent::setUp();
    }
    #endregion
}
